@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -64,6 +64,7 @@ typedef struct Cb
 
 int getParamType(char* tc)
 {
+        if (!tc) return TYPE_ERROR;
  	if (strcmp(tc,"int")==0) 	return TYPE_INT;
  	if (strcmp(tc,"uint")==0) 	return TYPE_UINT;
  	if (strcmp(tc,"double")==0) 	return TYPE_DOUBLE;
@@ -166,17 +167,37 @@ static void freeProxy(type_dp *proxy)
 
 static void freeProxies()
 {
-	logger("DBG", "freeProxy()");
+	logger("DBG", "freeProxies()");
         type_dp *tm;
 
         while (proxies != NULL) {
         	tm     = proxies;
                 proxies = proxies->next;
-		
 		freeProxy(tm);
         }
 }
 
+static void freeProxyByName(char *id)
+{
+	type_dp *prev = NULL;
+	type_dp *prox = findProxy(id, (type_dp**) &prev);
+	if (prox != NULL) { 
+		if (prox == proxies) { 	// remove in head
+			proxies = prox->next;
+		} else {
+			if (prev != NULL) {
+				prev->next = prox->next;
+			} else {
+				logger("ERR", "[EX]: freeProxyByName(): Previous item absent for non-first element");
+				return;
+			}
+		}       
+		freeProxy(prox);
+	} else {
+		logger("ERR", "[EX]: freeProxyByName(): no such dbus connection");
+	}
+}
+
 static void addProxy(char *id,char *s, char *p, char *i, DBusGProxy *proxy)
 {
 	logger("DBG", "addProxy()");      
@@ -249,6 +270,8 @@ int dbusInit()
 	GError *error = NULL;
  
  	g_type_init ();
+	
+	dbus_threads_init_default();
 
 	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (connection == NULL) {
@@ -282,7 +305,7 @@ int dbusCommand(char* cmdString)
 {
 	#ifdef USE_DBUS
 	GError   *error  = NULL;
-	gboolean retCode = FALSE;
+	gboolean retCode = TRUE;
 	
 	if (connection == NULL) {
 	        logger("ERR", "[EX]: dbusCommand(): no connection");  
@@ -324,23 +347,7 @@ int dbusCommand(char* cmdString)
 		} else if (strcmp(token,"close") == 0) {
 			logger("DBG", "[EX]: dbusCommand(): close");
 			
-			type_dp *prev = NULL;
-			type_dp *prox = findProxy(id, (type_dp**) &prev);
-			if (prox != NULL) { 
-        			if (prox == proxies) { 	// remove in head
-        				proxies = prox->next;
-        			} else {
-        				if (prev != NULL) {
-                				prev->next = prox->next;
-                			} else {
-                				logger("ERR", "[EX]: dbusCommand(): Previous item absent for non-first element");
-                        			return EXIT_NOK;
-                			}
-        			}       
- 				freeProxy(prox);
-			} else {
-				logger("ERR", "[EX]: dbusCommand(): no such dbus connection");
-			}
+			freeProxyByName(id);
 
 		} else if (strcmp(token,"set") == 0) {
 			logger("DBG", "[EX]: dbusCommand(): set");
@@ -367,12 +374,11 @@ int dbusCommand(char* cmdString)
 				char * type   = strtok(NULL,",");
 				char * value  = strtok(NULL,",");
 				
-				if (type != NULL && value != NULL) {
+				if (method != NULL && type != NULL && value != NULL) {
 					int sendType = getParamType(type);
 					DEBUG2("[EX]: dbusCommand(): method %s with 1 param of type %s",method,type);
 					
 					if (sendType == TYPE_INT) {
-	
 						retCode = dbus_g_proxy_call (prox->proxy, method, &error, 
 								G_TYPE_INT, atoi(value), 
 								G_TYPE_INVALID, G_TYPE_INVALID);
@@ -404,12 +410,18 @@ int dbusCommand(char* cmdString)
   					} else {
 						ERROR2("[EX]: dbusCommand(): unsupported param type %s",type); 
 					}
+					
+         				if (!retCode) {
+   						ERROR2("[EX]: dbusCommand(): failed in d-bus proxy call %s",method); 
+						g_object_unref(prox->proxy);
+						prox->proxy = NULL;
+ 					}
 				} else {
 					DEBUG2("[EX]: dbusCommand(): method %s with no params",method);
   					retCode = dbus_g_proxy_call (prox->proxy, method, &error, G_TYPE_INVALID, G_TYPE_INVALID);
 				}
 			} 
-			
+
 		} else if (strcmp(token,"get") == 0) {
 			logger("DBG", "[EX]: dbusCommand(): get");
 			
@@ -438,7 +450,7 @@ int dbusCommand(char* cmdString)
 				char * type   = strtok(NULL,",");
 				char * var    = strtok(NULL,",");
 				
-				if (type != NULL && var != NULL) {
+				if (method != NULL && type != NULL && var != NULL) {
 					int retType = getParamType(type);
 					int ret;
 					DEBUG2("[EX]: dbusCommand(): method %s with 1 param of type %s",method,type);
@@ -502,8 +514,7 @@ int dbusCommand(char* cmdString)
 						retCode = dbus_g_proxy_call (prox->proxy, method, &error, 
 								G_TYPE_INVALID, G_TYPE_STRING, rc, G_TYPE_INVALID);
 						
-						retVals[0]   = '\0';
-						retVals[511] = '\0';
+						memset(retVals,0,512);
 						if (rc != NULL) {
 							strncpy(retVals,rc,511);
 						}
@@ -516,11 +527,17 @@ int dbusCommand(char* cmdString)
   					} else {
 						ERROR2("[EX]: dbusCommand(): unsupported param type %s",type); 
 					}
+					
+        				if (!retCode) {
+   						ERROR2("[EX]: dbusCommand(): failed in d-bus proxy call %s",method); 
+						g_object_unref(prox->proxy);
+						prox->proxy = NULL;
+ 					}
 				} else {
-					logger("DBG", "[EX]: dbusCommand(): set with no ouprut params");
+					logger("DBG", "[EX]: dbusCommand(): set with no output params");
 				}
-			} 
- 
+ 			} 
+			
 		} else if (strcmp(token,"signal") == 0) {
 			logger("DBG", "[EX]: dbusCommand(): signal");
 			
