@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -49,7 +49,6 @@ extern int  isConnected;
 
 extern int  	    serverMode;
 extern char 	    callerId[MAXLEN];
-extern int  	    repeatNow;
 extern type_key*    repeatCmdPtr;
 extern char         tmp[MAXMAXLEN];
 
@@ -57,36 +56,174 @@ void macroCmd(char *descr, char *exec, cmdParams* params);
  
 char tmptext[MAXCMDLEN];
 int  remoteOn       = 1;
+//int  inForker       = 0;
 
-static int execInFork(const char *cmd)
+/*static int execInFork(const char *cmd)
 {
+        DEBUG2("execInFork >%s<", cmd);
         int cpid = fork();
         if( cpid < 0) {
         	logger("ERR", "Can not fork!");
+		printf("Can not fork!\n");
                 return -1;
         }
-
+        logger("INF", "Fork OK");
+	
         if(cpid) {      // father
-        	int rf = 0;
+        	int rf = 0;        
+		logger("INF", "WAID CHILD");
         	waitpid(cpid,&rf,0);
+	        if (WIFSIGNALED(rf) && (WTERMSIG(rf) == SIGINT || WTERMSIG(rf) == SIGQUIT)) {
+                 	printf("GOR ABORT ?");
+	        }
                 if(rf!=-1 && WIFEXITED(rf)) {
                 	rf = WEXITSTATUS(rf);
                 }
+		logger("INF", "CHILD FINISHED");
                 return rf;
         } 
         
         // else - child
-        int rc = 0;
-        //logger("INF", "Close port in child");
+	inForker = 1;
+	
         closePort(0);
-         
-        rc = system(cmd);
+        printf("execute >%s< command\n",cmd);
+        int rc = system(cmd);
+	printf("command executed %d\n", rc);
+        
+ 	if (WIFSIGNALED(rc) && (WTERMSIG(rc) == SIGINT || WTERMSIG(rc) == SIGQUIT)) {
+         	printf("GOR ABORT in child?");
+	}
         if(rc!=-1 && WIFEXITED(rc)) {
         	rc = WEXITSTATUS(rc);
         }
+	
+	printf("exit from child %d\n", rc);
         exit(rc);
 }
 
+static int execInForkSimple()
+{
+        logger("DBG","execInForkSimple");
+        int cpid = fork();
+        if (cpid < 0) {
+        	logger("ERR", "Can not fork!");
+		printf("Can not fork!\n");
+                return -1;
+        }
+        logger("INF", "Fork OK");
+	
+        if (cpid) {      // father
+        	int rf = 0;        
+		logger("INF", "WAID CHILD");
+        	waitpid(cpid,&rf,0);
+                if(rf!=-1 && WIFEXITED(rf)) {
+                	rf = WEXITSTATUS(rf);
+                }
+		logger("INF", "CHILD FINISHED");
+                return rf;
+        } 
+        
+        // else - child
+	inForker = 1;
+	printf("fork OK\n");
+	
+	char* file[2];
+	file[0] = getCmdFile();
+        if (file[0] == NULL) {
+		printf("execNoForkSimple: can not get file name !");
+		return -1;
+	}
+	file[1] = NULL;
+	
+        closePort(0);
+	
+        struct stat buf;
+	if (stat(file[0], &buf) == -1) {
+	        printf("There is not command file !\n");
+		return -1;
+	}
+
+	printf("about to execute command\n");
+        int rc = execvp("sh",file);
+	printf("command executed %d\n", rc);
+	
+	printf("exit from child %d\n", rc);
+        exit(rc);
+}
+*/
+static int execNoFork(const char *cmd)
+{
+        DEBUG2("execNoFork >%s<", cmd);
+        
+	//printf("execute >%s< command\n",cmd);
+        /*int rc =*/ system(cmd);
+	//printf("command executed %d\n", rc);
+        
+ 	/*if (WIFSIGNALED(rc) && (WTERMSIG(rc) == SIGINT || WTERMSIG(rc) == SIGQUIT)) {
+         	printf("GOR ABORT in system?");
+	}
+        if(rc!=-1 && WIFEXITED(rc)) {
+        	rc = WEXITSTATUS(rc);
+		
+        }*/
+	//printf("exit from child %d\n", rc);
+        return 0;
+}
+
+/*static int execNoForkSimple()
+{
+        DEBUG2("execNoForkSimple");
+ 
+	char* file[2];
+	file[0] = getCmdFile();
+        if (file[0] == NULL) {
+		printf("execNoForkSimple: can not get file name !");
+		return -1;
+	}
+	file[1] = NULL;
+	
+        closePort(0);
+	
+        struct stat buf;
+	if (stat(file[0], &buf) == -1) {
+	        printf("execNoForkSimple: There is not command file !\n");
+		return -1;
+	}
+
+	printf("about to execute command\n");
+        int rc = execvp("sh",file);
+	printf("command executed %d\n", rc);
+
+	printf("exit from child %d\n", rc);
+        return rc;
+}
+*/
+
+/*static int writeCommandFile(const char *cmd) 
+{
+	char* file = getCmdFile();
+        if(file == NULL) {
+		logger("ERR","writeCommandFile: can not get file name !");
+		return EXIT_NOK;
+	}
+        
+	FILE *fp=fopen(file,"w");
+	if (fp == NULL) {
+		ERROR2("writeCommandFile: can not open file %s !",file);
+		return EXIT_NOK;
+	}
+
+        int n = fwrite(cmd,1,strlen(cmd),fp); 
+	int ret = EXIT_OK;       
+        if (n < 0) {
+        	ERROR2("writeCommandFile: error writing to file %s !",file);
+		ret = EXIT_NOK;
+        }
+	fclose(fp);
+	return ret;
+}*/
+
 static char resBuffer[1024];
 
 static char *readResultsFile(int * count) 
@@ -440,6 +577,7 @@ static int execSimpleCmd(const char *cmd, int toFile)
         } else {
         	add = 2;
         }
+
 	char* p = calloc(strlen(cmd) + add,1);
         if (p == NULL) {
         	return EXIT_NOK;
@@ -450,13 +588,27 @@ static int execSimpleCmd(const char *cmd, int toFile)
         	strcat(p, " > ");		
                 strcat(p, getResFile());
         } else {
-        	if (! index(p, '&')) {
+        	if (!index(p, '&')) {
                 	strcat(p, "&");
                 }
         }
-        int ret = execInFork(p);
-        free(p);
+	
+	int ret;
+        //ret = execInFork(p);
+        ret = execNoFork(p);
+	
+	/*if (writeCommandFile(p) == EXIT_OK) {
+        	//ret = execInForkSimple();
+        	ret = execNoForkSimple();
+        	free(p);
         
+		DEBUG2("execSimpleCmd EXIT >%s<", cmd);
+	} else {
+		logger("DBG", "Can not write command file!");
+		ret = -1;
+	}*/
+	
+	free(p);
         return (ret == -1 ? EXIT_NOK : EXIT_OK);
 }
 
@@ -466,6 +618,8 @@ static int processSendCmd(char* sDescr)
 	int ret = EXIT_OK;
 
         char all[MAXMAXLEN];
+	memset(all,0,MAXMAXLEN);
+	
         strncpy(all, sDescr, MAXMAXLEN-1);
 
         char *tag  = strtok(all, ",");
@@ -579,6 +733,7 @@ static int loadCmds(char *file)
 	
 	if (file_status.st_size <= 0) {
 		logger("DBG","loadCmds - file is empty");
+		fclose(fp);
 		return EXIT_NOK;
 	}
 	
