@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ int   getModel          (void);
 int   getRetrySecs  	(void);
 int   getUseScreen      (void);
 int   getHttp           (void);
+int   getIViewer        (void);
 int   usePassword       (void);
 void  addAlarm		(char *file, char *macro);
 void  freeCfg           (void);
@@ -52,6 +53,9 @@ void  printConf         (void);
 void  printKeys		(void);
 void  setModel          (char *m);
 
+void setRepeatNow       (type_key *k);
+type_key* repeatNow     ();
+
 type_key* findItem	(char *key, int *flag, cmdParams *param);
 cmdItem* getCommand	(type_key* item);
 
