@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -245,20 +245,18 @@ void closePort(int final)
 	#endif
 	} else if (serverMode == CLIENT_ILIRC) {
         	if (unix_close_port() < 0) {
-                	logger("ERR","[DS]: Error on closing AF_UNIX socket\n");
+                	if (final) logger("ERR","[DS]: Error on closing AF_UNIX socket\n");
                 }
         } else if (serverMode == CLIENT_AT || serverMode == CLIENT_NOAT) {
         	if (bt_close_port(final) < 0) {
-                	logger("ERR","[DS]: Error on closing port\n");
+                	if (final) logger("ERR","[DS]: Error on closing port\n");
                 }
         } else if (serverMode == SERVER_STDIN && final) {
         	closeStdin();
         }
 
 	if (getFrontEnd() > 0) {
-		if (final)  {
-			sendToFrontEnd("Exiting");
-                }
+		if (final) sendToFrontEnd("Exiting");
                 // else - just close socket from forked child
 		disconnectFrontEnd();
 	}
@@ -340,6 +338,7 @@ static int checkMsgQueue()
 			char *msgIn = (char*) dm->value;
 		
 	        	if (dm->type == DM_SET) {
+			
 	        		logger("DBG", "[DS]: Set()");
 				writeSocketConn(msgIn, dm->size);
 			
@@ -421,7 +420,7 @@ void parseCommand(char* cmd)
 		next = strchr(cmd, '\3');		// end-of-text marker in CommandFusion
 	}
 	if (next) {
-		logger("DBG", "parseCommand multiline");
+		logger("DBG", "[DS]: parseCommand multiline");
 
 		char copy[1024];
 		int len;
@@ -460,7 +459,7 @@ void parseCommand(char* cmd)
 	if (strncmp(cmd, "AT+CKPD=", 8) == 0) {        // This is echo of sent message in AT mode; nothing to do
 		return;
 	}
-\
+	
 	if (strncmp(cmd, "Msg:_DEBUG_(", 12) == 0) {   // This is debug message from java client; nothing to do
 		return;
 	}
@@ -479,6 +478,19 @@ void parseCommand(char* cmd)
  			hack = 1;
 		}
 	}
+	
+        // This is heartbeat of iViewer; answer to it fast
+	if (strncmp(cmd, "h=0", 3) == 0 && getIViewer()) {  
+		logger("DBG", "[DS]: Got heartbeat message from iViewer; auto-reply to it");
+		 
+		// it is a trick, we do not want to waste a time to handle message 
+		// through normal "shell" cycle
+		sendIViewerHeartbeat();
+		
+		// propagate event to executor anyway 
+		// (to be able to disconnect in case of client dying)
+	}
+
  
  	eMessage* em = malloc(sizeof(eMessage));
 	em->type  = EM_KEY;
@@ -490,6 +502,7 @@ void parseCommand(char* cmd)
 	} else {
 		em->value = strdup(cmd);
 	}
+	logger("DBG", "[DS]: Send message to executor thread");
 	sendToExecutor(em);
 	
 	return;
@@ -520,7 +533,7 @@ static int read_command(char* buf, int l)
                 	return 0;
 		} else {
 		        len = strlen(buf);
-                        DEBUG2("read_command SERVER_STDIN %d %s\n", len, buf);
+                        DEBUG2("[DS]: read_command SERVER_STDIN %d %s\n", len, buf);
                 }
 	} else {
 
@@ -552,18 +565,18 @@ int initPort()
 	char answer[1024];
         char cmd[32];
 
-        logger("DBG","initPort");
+        logger("DBG","[DS]: initPort");
 
         if (serverMode == SERVER_BT  || 
 	    serverMode == SERVER_TCP || 
 	    serverMode == SERVER_UX) {	// Wait for incoming connection
-                logger("INF", "Server mode: Waiting connection");
+                logger("INF", "[DS]: Server mode: Waiting connection");
                 return listenAndAcceptSocketConn(serverMode);
         } 
 
 	#ifdef USE_L2CAP	
         if (serverMode == SERVER_L2CAP) {
-                logger("INF", "Server mode/L2CAP: Waiting connection");
+                logger("INF", "[DS]: Server mode/L2CAP: Waiting connection");
                 return listenAndAcceptL2capConn();
 	} 
 	#endif
@@ -571,7 +584,7 @@ int initPort()
 	if (serverMode == CLIENT_ILIRC || 
 	    serverMode == CLIENT_NOAT  ||
 	    serverMode == SERVER_STDIN) {
-		logger("INF", "Unix client: init OK");
+		logger("INF", "[DS]: Unix client: init OK");
 		return 1;	// nothing to init
 	}
 	
@@ -650,7 +663,7 @@ gpointer dispatcherRoutine(gpointer thread)
 
 	logger("DBG","[DS]: start dispatcher thread");
 
-	setResFile();
+	setCmdFiles();
 	
 	// wait init ok event
 	while (1) {
@@ -861,8 +874,8 @@ gpointer dispatcherRoutine(gpointer thread)
 					break;
 				}
 				
-	    	    		// Main loop timer (1/20 of second)
-		    		usleep(50000);
+	    	    		// Main loop timer (1/50 of second)
+		    		usleep(20000);
 		 	}  
 		    }	// init port
 		}	// open port
