@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -71,9 +71,6 @@ static void cleanAutoRepeatFlag();
 int  commandTimer = 0;
 int  repeatTimer  = 0;
 
-int  repeatNow    = 0;
-type_key*  repeatCmdPtr = NULL;
-
 char modifierString [MAXARGLEN];
 
 int  flushConf    = 0;
@@ -112,9 +109,11 @@ gpointer executorRoutine(gpointer thread)
 	int exitFlag = 0;
 	
 	dbusInit();
+	logger("INF","[EX]: DBUS initialized");
 	handleInit();
-                
-	logger("INF", "Send init OK event to dispatcher");
+ 	logger("INF","[EX]: init hooks done");
+               
+	logger("INF", "[EX]: Send init OK event to dispatcher");
 	dMessage* dm = malloc(sizeof(dMessage));
 	dm->size  = 0;
 	dm->value = (void*) NULL;
@@ -122,16 +121,20 @@ gpointer executorRoutine(gpointer thread)
 	sendToDispatcher(dm);
 	
 	while (stillRun) {
-	
+	  
+		//logger("DBG", "[EX]: LOOP");
+		
 		eMessage *em = (eMessage *) g_async_queue_try_pop(q2exec);
 		
 		if (em != NULL) {
-		
+		        
+		        logger("DBG", "[EX]: got event");
+			
 			if (em->type == EM_KEY) {
 			
 				char * cmd = (char *) em->value;
 			
-				sprintf(tmp, "[EX]: got key >%s<", cmd);
+				sprintf(tmp, "[EX]: got key >%s<", (cmd ? cmd : "NULL"));
 				logger("DBG", tmp);
 				
 				handle_command(cmd);
@@ -206,9 +209,10 @@ gpointer executorRoutine(gpointer thread)
 				return NULL;
 			}
 		}
+		//logger("DBG", "[EX]: command processed of empty input");
 		
 	    	// Should we auto-repeat command (timeout about 1/10 second) ?
-	    	if (repeatNow) {
+	    	if (repeatNow() && getAutoRepeat()) {
 			int isOdd = ((int)repeatTimer/2)*2;
 			
 			if (repeatTimer > 100) {  // Check for infinite loop. Only 50 autorepeats per one press
@@ -216,7 +220,7 @@ gpointer executorRoutine(gpointer thread)
 	    		} else if (repeatTimer > 0 && isOdd == repeatTimer) {
 	    			DEBUG2("[EX]: Auto repeat command ... (%d)", repeatTimer);
 
-	    			handleCmdByKey(repeatCmdPtr,NULL);
+	    			handleCmdByKey(repeatNow(),NULL);
 	    	
 				repeatTimer++;
 	    		} else {
@@ -224,9 +228,10 @@ gpointer executorRoutine(gpointer thread)
 	    			repeatTimer++;
 	    		}
 	    	}
-
+		
+ 		//DEBUG2("[EX]: check timers(%d)", commandTimer);
 		// Verify commands executed by timer (timeout about 1 sec)
-	    	if (commandTimer == 20) {
+	    	if (commandTimer == 50) {
 	    		//logger("DBG","[EX]: Verify timer commands ...");
 	    		verifyTimers(1) ;
 	    		commandTimer = 0;
@@ -235,9 +240,13 @@ gpointer executorRoutine(gpointer thread)
 	    		commandTimer++;
 	    	}
 		
-		if (!stillRun) break;
+		if (!stillRun) {
+			logger("DBG","[EX]: Break from loop ...");
+			break;
+		}
 		
-		usleep(50000); // loop timer (1/20 of second)
+		//logger("DBG", "[EX]: wait a bit");
+		usleep(20000); // loop timer (1/50 of second)
 	}
 	
 	return NULL;
@@ -330,15 +339,16 @@ static void cleanAutoRepeatFlag()
 {
 	// Clear auto repeat flag
 	logger("DBG","[EX]: Clean auto repeat flag");
-	repeatNow    = 0;
-	repeatCmdPtr = NULL;
+	setRepeatNow(NULL);
 	repeatTimer  = 0;
 }
 
 static int handle_alarm(char* key) 
 {
-        DEBUG2("[EX]: handle_alarm() >%s<", key);
-
+        DEBUG2("[EX]: handle_alarm() >%s<", (key ? key : "NULL"));
+	
+        if (!key) return EXIT_OK;
+	
         int i;
         cmdParams params;
         type_key *k = findItem(key , &i, &params);
@@ -361,7 +371,8 @@ static int handle_alarm(char* key)
 
 static int handle_key_press(char* key,int isRepeatable) 
 {
-        DEBUG2("[EX]: handle_key_press() >%s<", key);
+        DEBUG2("[EX]: handle_key_press() >%s<", (key ? key :  "NULL"));
+	if (!key) return EXIT_OK;
 	
 	sendToFrontEnd(key);
 
@@ -378,11 +389,10 @@ static int handle_key_press(char* key,int isRepeatable)
         type_key *k = findItem((modifierString[0] == '\0' ? key : modifierString), &i, &params);
 
         if (k && i == FLAG_EXACT) {
-        	if (isRepeatable && (!repeatNow) && getAutoRepeat()) {
+        	if (isRepeatable && (!repeatNow()) && getAutoRepeat()) {
                 	logger("DBG", "Set auto repeat flag");
-                        repeatNow    = 1;
-                        repeatCmdPtr = k;
-                } 
+                        setRepeatNow(k);
+                 } 
                 handleCmdByKey(k, NULL);
                     
                 // Clean modifier string
@@ -435,6 +445,8 @@ static int handle_command(char* cmd)
 {
 	logger("DBG","[EX]: handle_command");
 	
+	if (!cmd) return EXIT_OK;
+	
 	char *key = NULL;
 	
 	if (memcmp(cmd, DEF_CLDEBUG, 12) == 0) {	    // Got debug event from Java client
@@ -498,9 +510,8 @@ static int handle_command(char* cmd)
 		} else if (key[i] == '0') {
 			//logger("DBG","[EX]: Button up event");
 			// In general we skip this
-			if (repeatNow) {
-				cleanAutoRepeatFlag();
-			}
+			cleanAutoRepeatFlag();
+
 			return EXIT_OK;
 		} else {
 			DEBUG2("[EX]: something wrong: key should be pressed or released: cmd=>%s< char=>%c<",cmd, key[i]);
@@ -616,6 +627,8 @@ static int isBemusedCommand(char *cmdIn)
                 int shift  = 4;
 
                 char oneCmd[10];
+		memset(oneCmd,0,10);
+		
                 char paramValue[8];
                 paramValue[0] = '\0';
 
