@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ int connectFrontEnd(int portno)
 	if (portno <= 0) {
 		portno = 5050;
 	}
-	sockfd_fe = socket(AF_INET, SOCK_STREAM, 0);
+	sockfd_fe = socket(AF_INET, SOCK_STREAM|SOCK_CLOEXEC, 0);
 	if (sockfd_fe < 0) {
 		logger("ERR", "opening socket for frontend");
 		return EXIT_NOK;
