@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2009 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2009,2010 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -177,7 +177,7 @@ int openL2capPort(int port)
 		return 1;
 	}
 
-	if ((sportfd = socket(PF_BLUETOOTH, SOCK_SEQPACKET, BTPROTO_L2CAP)) < 0) {
+	if ((sportfd = socket(PF_BLUETOOTH, SOCK_SEQPACKET|SOCK_CLOEXEC, BTPROTO_L2CAP)) < 0) {
 		logger("ERR", "opening socket");
 		printf("ERROR: opening socket\n");
 	
@@ -320,6 +320,7 @@ int writeBytesL2capConn(char* command)
 	if (command && command[0]) {
 		
 		char byteStr[MAXCKPDLEN];
+		memset(byteStr,0,MAXCKPDLEN);
 		strncpy(byteStr,command,MAXCKPDLEN-1);
 
 		sprintf(tmp, "writeL2capSocketConn >%s<", byteStr);
